Constants class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- primaryColor → Color
-
final
- secondaryColor → Color
-
final
Static Methods
-
permissionRequiredContent(
String name) → String -
permissionRequiredTitle(
String name) → String -
videoSizeExceeded(
String filename) → String
Constants
- camera → const String
- cancel → const String
- compressingVideo → const String
- galleryAccessRequired → const String
- galleryAccessRequiredSubtitle → const String
- noMediaFound → const String
- noMediaFoundSubtitle → const String
- openSettings → const String
- processingMedia → const String