InteractiveCropView class

An interactive crop view widget featuring:

  • Freeform custom crop (drag edges and corners freely)
  • Aspect ratio locked crop (1:1, 16:9, etc.)
  • Pan crop box across image
  • Semi-transparent mask, rule-of-thirds grid, and stylish corner/edge handles
Inheritance

Constructors

InteractiveCropView({Key? key, required Uint8List imageBytes, required int imageWidth, required int imageHeight, required Rect cropRect, required ValueChanged<Rect> onCropRectChanged, double? targetAspectRatio, int rotationDegrees = 0, bool flipHorizontal = false})
const

Properties

cropRect → Rect
final
flipHorizontal → bool
final
hashCode → int
The hash code for this object.
no setterinherited
imageBytes → Uint8List
final
imageHeight → int
final
imageWidth → int
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onCropRectChanged → ValueChanged<Rect>
final
rotationDegrees → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetAspectRatio → double?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<InteractiveCropView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited